# python-weka-wrapper3

Python wrapper for the Java machine learning workbench [Weka](http://www.cs.waikato.ac.nz/~ml/weka/)
using the [javabridge](https://pypi.python.org/pypi/javabridge) library.

Requirements:

* Python 3
  * javabridge (>= 1.0.14)
  * matplotlib (optional)
  * pygraphviz (optional)
  * PIL (optional)
* JDK 8 or later (OpenJDK 11 recommended)

Uses:
* Weka (3.9.5)


## Installation

Detailed instructions on installing the library on various operating systems are located here:

https://fracpete.github.io/python-weka-wrapper3/install.html

Please note, that you need a build environment to compile some libraries from source.


## Forum

You can post questions, patches or enhancement requests in the following Google Group:

https://groups.google.com/forum/#!forum/python-weka-wrapper


## Examples

* The [Examples](https://fracpete.github.io/python-weka-wrapper3/examples.html)
  section in the documentation demonstrates how to use the API. 
* The [python-weka-wrapper-examples3](https://github.com/fracpete/python-weka-wrapper3-examples)
  repository contains plenty of example code for the various APIs.


## Documentation

The complete documentation for the library is available from here:

https://fracpete.github.io/python-weka-wrapper3/


## Download statistics

For viewing recent download statistics, go to *pypistats*:

https://pypistats.org//api/packages/python-weka-wrapper3/recent
